# Divergent Gravity

Some useful utilities for working with the divergent gravity framework.

Explore this package if you like, but be aware that this is still in the exploratory phase and is not meant to be a perfect representation of the model.
